"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

exports.__esModule = true;
exports["default"] = exports.debugLevels = void 0;

var _debug = _interopRequireWildcard(require("debug"));

exports.Debug = _debug.Debug;
var logLevels = ['log', 'error', 'warn', 'debug', 'info', 'verbose'];
var defaultLogLevel = logLevels[2];

var emptyFunction = function emptyFunction() {
  /* no-op */
};

var debugLevels = function debugLevels(debugProvider, envProvider, namespace) {
  var logLevel = defaultLogLevel;
  var debugLevelEnv = envProvider.DEBUG_LEVEL;

  if (debugLevelEnv != null) {
    logLevel = debugLevelEnv;
  }

  if (logLevels.indexOf(logLevel) < 0) {
    debugProvider(namespace)("Attempted to set unsupported DEBUG_LEVEL=\"" + logLevel + "\", so fallback to default level \"" + defaultLogLevel + "\"");
    logLevel = defaultLogLevel;
  }

  if (!envProvider.hasOwnProperty('DEBUG')) {
    debugProvider.enable('resolve:*');
  }

  var allowedLevels = logLevels.slice(0, logLevels.indexOf(logLevel) + 1);
  var originalLogger = debugProvider(namespace);
  return Object.assign(originalLogger.bind(null), {
    log: allowedLevels.indexOf('log') > -1 ? originalLogger : emptyFunction,
    error: allowedLevels.indexOf('error') > -1 ? originalLogger : emptyFunction,
    warn: allowedLevels.indexOf('warn') > -1 ? originalLogger : emptyFunction,
    debug: allowedLevels.indexOf('debug') > -1 ? originalLogger : emptyFunction,
    info: allowedLevels.indexOf('info') > -1 ? originalLogger : emptyFunction,
    verbose: allowedLevels.indexOf('verbose') > -1 ? originalLogger : emptyFunction
  });
};

exports.debugLevels = debugLevels;
var envProvider = {};

try {
  envProvider = process.env;
} catch (error) {}

var _default = debugLevels.bind(null, _debug["default"], envProvider);

exports["default"] = _default;
//# sourceMappingURL=index.js.map